#!/usr/bin/env python
# -*- coding: iso-8859-15 -*-

import wx
import os

wx.SetDefaultPyEncoding("iso-8859-15")

APPDIR = os.path.dirname(os.path.abspath(__file__))


class HintergrundPanel(wx.Panel):
    
    def __init__(self, parent):
        wx.Panel.__init__(self, parent)
        self.Bind(wx.EVT_PAINT, self.on_paint)
        self.bmp = wx.Bitmap(os.path.join(APPDIR, "images", "hintergrund_01.png"))
        self.SetClientSize(self.bmp.GetSize())
        self.SetSizeHintsSz(self.GetSize())
        self.Fit()
    

    def on_paint(self, event):
        dc = wx.BufferedPaintDC(self, self.bmp)
        event.Skip()


class SpielfeldPanel(wx.Panel):

    def __init__(self, parent):
        wx.Panel.__init__(self, parent, style = wx.TRANSPARENT_WINDOW)
        self.Bind(wx.EVT_PAINT, self.on_paint)
        self.bmp = wx.Bitmap(os.path.join(APPDIR, "images", "spielfeld_02.png"))
        self.SetClientSize(self.bmp.GetSize())
        self.SetSizeHintsSz(self.GetSize())
        self.Fit()
    

    def on_paint(self, event):
        dc = wx.BufferedPaintDC(self, self.bmp)
        event.Skip()


class KugelWindow(wx.Window):
    
    def __init__(self, parent):
        wx.Window.__init__(self, parent, style = wx.TRANSPARENT_WINDOW)
        
        self.bmp = wx.Bitmap(os.path.join(APPDIR, "images", "kugel_01.png"))
        self.SetClientSize(self.bmp.GetSize())
        self.SetSizeHintsSz(self.GetSize())
        self.Fit()
        
        self.Bind(wx.EVT_LEFT_DOWN, self.on_left_down)
        self.Bind(wx.EVT_LEFT_UP, self.on_left_up)
        self.Bind(wx.EVT_MOTION, self.on_motion)
        self.Bind(wx.EVT_PAINT, self.on_paint)
    
    
    def on_paint(self, event):
        dc = wx.BufferedPaintDC(self, self.bmp)
        event.Skip()
    

    def on_left_down(self, evt):
        self.CaptureMouse()
        x, y = self.ClientToScreen(evt.GetPosition())
        originx, originy = self.GetPosition()
        dx = x - originx
        dy = y - originy
        self.mp_delta = ((dx, dy))


    def on_left_up(self, evt):
        if self.HasCapture():
            self.ReleaseMouse()


    def on_motion(self, evt):
        if evt.Dragging() and evt.LeftIsDown():
            x, y = self.ClientToScreen(evt.GetPosition())
            fp = (x - self.mp_delta[0], y - self.mp_delta[1])
            self.Move(fp)     
    

class MyFrame(wx.Frame):
    
    def __init__(self, parent = None, title = "Spiel"):
        wx.Frame.__init__(self, parent, -1, title)
        
        hintergrund_panel = HintergrundPanel(self)
        hintergrund_sizer = wx.BoxSizer(wx.VERTICAL)
        hintergrund_panel.SetSizer(hintergrund_sizer)
        
        spielfeld_panel = SpielfeldPanel(hintergrund_panel)
        hintergrund_sizer.Add(spielfeld_panel, 1, wx.EXPAND)
        
        kugel1 = KugelWindow(spielfeld_panel)
        
        self.Fit()
        self.SetSizeHintsSz(self.GetSize())
    

class MyApp(wx.PySimpleApp):
    
    def OnInit(self):
        
        frame = MyFrame()
        frame.Center()
        frame.Show()
        
        return True


def main():
    app = MyApp()
    app.MainLoop()


if __name__ == "__main__":
    main()
